# Installation

Um Vision zu installieren muss erst das Projektarchiv in den Modulpfad
entpackt werden. Dies ist standardmäßig:

`/usr/share/icingaweb2/modules/vision`

Um den weiteren Installationsverlauf zu vereinfachen und die Befehle aus dieser Anleitung per Copy-Paste verwenden zu
können, empfielt es sich, diesen Pfad für die Sitzung als Umgebungs-
Variable zu definieren:

```bash
export VISIONPATH="/usr/share/icingaweb2/modules/vision"
```

## Voraussetzungen

- IcingaWeb2 2.11+
- PHP 8.1
- sgloader PHP-Erweiterung für PHP 8.1

### Thumbnails/Screenshots mit Status

- pkill
- Chromium oder Chrome
- IcingaWeb2 und Icinga2 müssen auf demselben Host laufen, damit die automatischen Services genutzt werden können

## 1. SourceGuardian Loader

Da das Modul mit Source-Guardian verschlüsselt ist, muss Source-Guardian
**vor** der Installation von Vision installiert werden.

Zunächst muss der SourceGuardian-Loader von der offiziellen Website heruntergeladen werden:

`https://www.sourceguardian.com/loaders.html`

Das Paket entpacken und die Datei `ixed.8.1.lin` (bzw. die für die verwendete PHP-Version korrekte
Datei) in das PHP-Erweiterungs-Verzeichnis kopieren (Betriebssystem-abhängig)

Anschließend das Modul in der `cli/php.ini` aktivieren.  
Wird der Director verwendet, muss das Modul zusätzlich in der `apache2/php.ini` aktiviert werden.

Nach der Source-Guardian Installation kann das Modul installiert werden.

## 2. Installation Vision

### 2.1 Entpacken

```bash
tar -xvzf  vision-2.0.0-PHP8.1.tar.gz ${VISIONPATH}  --no-same-owner

mv ${VISIONPATH} /Vision... ${VISIONPATH} /vision

chmod 775 ${VISIONPATH} /vision/ -R
```

### 2.2 Lizenz

Es wird auf root-Ebene des Moduls eine Lizenzdatei benötigt: `${VISIONPATH}/license.lic`. Ohne eine
gültige Lizenz kann Vision nicht verwendet werden.

> ACHTUNG: Ist Vision vorhanden und es existiert keine gültige Lizenz-Datei funktioniert icingaweb2
> nicht mehr richtig.

### 2.3 Berechtigungen

Um Vision-Thumbnails benutzen zu können müssen einige Rechte gesetzt
werden. Der im Beispiel verwendete "**apache**" Nutzer ist der
**Systemabhängige Webserver Nutzer** und kann sich je nach Sytem unterscheiden.

```bash
chown apache:apache -R ${VISIONPATH}/public/img/thumbnail-diagram

chown apache:apache -R ${VISIONPATH}/public/img/thumbnail-template

chown apache:apache -R ${VISIONPATH}/public/img/uploads
```

Um die erweiterten Thumbnails mit Statuswerten zu erstellen ist es
notwendig noch mehr Änderungen vorzunehmen. Das Icingashot-Script
braucht alle nötigen Berechtigungen.

```bash
chown apache:nagios -R ${VISIONPATH}/public/img/thumbnail-status

chown nagios:nagios ${VISIONPATH}/library/Vision/Screenshot/icingashot

chmod 777 ${VISIONPATH}/public/img/thumbnail-status

chmod +x ${VISIONPATH}/library/Vision/Screenshot/icingashot
```

#### All-in-one-Command

```bash
export VISIONPATH="/usr/share/icingaweb2/modules/vision" && \
chmod 775 $VISIONPATH -R && \
chown www-data:www-data -R $VISIONPATH/public/img/thumbnail-diagram && \
chown www-data:www-data -R $VISIONPATH/public/img/thumbnail-template && \
chown www-data:www-data -R $VISIONPATH/public/img/uploads && \
chown www-data:nagios -R $VISIONPATH/public/img/thumbnail-status && \
chown nagios:nagios $VISIONPATH/library/Vision/Screenshot/icingashot && \
chmod 777 $VISIONPATH/public/img/thumbnail-status && \
chmod +x $VISIONPATH/library/Vision/Screenshot/icingashot
```

Außerdem muss für die erweiterten Thumbnails der Webbrowser Chrome installiert werden, denn über
diesen werden die Thumbnails Serverseitig erstellt. Später kann dies über die Moduleinstellungen im
IcingaWeb2 aktiviert werden.

### 2.4 Datenbank

Die Datenbank muss erstellt und konfiguriert werden.

```bash
mysql -uroot -p[PASSWORD] < ${VISIONPATH}/schema/schema.sql

mysql -p[PASSWORD] vision
```

```sql
CREATE USER 'vision'@'localhost' IDENTIFIED BY '<password>';

GRANT ALL PRIVILEGES ON vision . * TO 'vision'@'localhost';

FLUSH
PRIVILEGES;
```

Um die mitgelieferten Figuren und Templates zu installieren müssen diese
in die Datenbank geladen werden.

```bash
mysql -uroot -p[PASSWORD] vision < ${VISIONPATH}/schema/templates.sql
```

### 2.5 Konfigurationsdatei

Die Konfigurationsdatei muss in das conf.d verzeichnis von Icinga
kopiert werden. Es müssen folgende Änderungen an der Konfigurationsdatei
vorgenommen werden:

- User/Passwort des APIUsers bei Bedarf anpassen.

- User/Passwort des APIUsers bei Bedarf in den Checkcommand Argumenten anpassen.

Danach muss die Icingaconfig neu geladen werden.

```
mv -v ${VISIONPATH}/library/Vision/Configuration/vision.conf /etc/icinga2/conf.d/

service icinga2 reload
```

Wenn nicht bereits das gesamte `conf.d`-Verzeichnis über die `/etc/icinga2/icinga2.conf` inkludiert
wird muss folgende Zeile an das Ende der `icinga2.conf` angehängt werden:

```conf
include "conf.d/vision.conf"
```

Um den Debugmode zu aktivieren muss lediglich der "Debug" Parameter in
der `vision.conf` einkommentiert werden.

### 2.6 Konfiguration in Icinga

#### User

Nun muss ein User mit dem Namen "vision" angelegt werden.

Der User "vision" benötigt eine Rolle mit der folgenden Permission:

Allow access to module vision (module/vision)

#### Ressource

Die "vision" Ressource muss im Icingaweb2 Frontend angelegt werden.

Configuration → Application → Resources

# Konfiguration

Über IcingaWeb2 können Konfigurationen am Modul vorgenommen werden.
Diese sind zu erreichen unter Konfiguration → Module → Vision.

![](images/module_configuration.jpg)

## Status Thumbnails

Gibt an, ob Diagamm-Thumbnails mit Statusfarben generiert werden sollen oder nicht.

> Damit `icingashot` richtig funktionieren kann, muss `pkill` installiert sein. Sonst kann es dazu kommen, dass die
> geöffnet Browser-Instanzen nicht wieder geschlossen werden und das System Out-of-memory geht.

## Base address

Definiert die Adresse, unter der IcingaWeb2 für den icingashot-Dienst erreichbar ist. Im Normalfall
`http://localhost/icingaweb2`.

## Status Diagrams

Sobald Status Thumbnails aktiviert sind, wird für den Host "Vision" pro
Diagramm, welche in dem Feld Status Diagrams hinterlegt sind, ein Service "thumbnail\_\[NAME\]" angelegt.

Beim Speichern der eingetragenen Diagramme wird ein Script ausgeführt,
welches das neue Thumbnail mit den Statusfarben
generiert.

Um genauere Informationen zum Script-Ablauf zu erhalten, kann das
'debug'-Flag in der `vision.conf` einkommentiert werden (s.
Installation → [Konfigurationsdatei](#25-konfigurationsdatei))

Wenn sie mit Statuswerten generiert werden sollen, wird Chrome/Chromium
auf dem Server benötigt.

## Thumbnail User

Benutzername für den Vision-User, der über IcingaWeb2 angelegt wurde.

## Thumbnail Passwort

Passwort für den Vision-User, der über IcingaWeb2 angelegt wurde.

## API User

Benutzername für den API-User, der über die vision.conf angelegt wurde.

## API Passwort

Passwort für den API-User, der über die vision.conf angelegt wurde.

# Berechtigungen

> ab v2.0.0

Über Rollen können für Vision verschiedene Berechtigungen vergeben werden.

![Rollen-Berechtigungen](images/role_config.jpg)

## Full Module Access

Aktiviert volle Berechtigungen für das Modul.

> ACHTUNG: Die Präfix-Restriktionen greifen trotzdem.

## General Module Access

Steuert den generellen bzw. lesenden Zugriff auf das Vision Modul. Rollen mit diesem Recht erlauben den
Zugriff auf die Vision-Ansichten sowie lesenden Zugriff auf alle Elemente (Diagramme, Tags, Templates).

## vision/edit

Rollen mit diesem Recht können neue Objekte (Diagramme, Tags, Templates) anlegen, bearbeiten und löschen.

User, die dieses Recht nicht haben, sehen die Tag- und Diagramm-Hinzufügen Buttons nicht und können auch nicht den
Bearbeitungsmodus eines Diagrams aufrufen.

## Restrictions - vision/prefix

Über die Restriktion `vision/prefix` kann genauer gesteuert werden, auf welche Diagramme die Rolle Zugriff hat.

Über eine Komma-separierte Liste können Diagramm-Präfixe eingetragen werden. Die Rolle hat nur Zugriff auf die
Diagramme, die mit diesen Präfixen anfangen.

> ACHTUNG: Die Präfix-Restriktionen funktionieren NUR unter dem neuen `icingadb`-Backend. Das alte `IDO`-Backend
> unterstützt diese Funktion nicht.

# Übersicht

Die Übersicht zeigt alle aktuellen Diagramme und Tags an. Von hier aus
werden Diagramme erstellt und gelöscht, sowie in den
[Ansichts-](#diagram-ansicht) oder [Bearbeitungs-Modus](#diagramm-editor)
gewechselt.

![](images/overview_new.png)

## Diagramme

Sobald ein Diagramm über die Übersicht angelegt wurde, können Tags
hinzugefügt werden und das Diagramm kann bearbeitet werden. Sobald die
Maus über das Diagramm bewegt wird, erscheint ein Menü:

![](images/Hover.png)

Hier kann in der oben Hälfte den [Ansichts-](#diagram-ansicht) oder
[Bearbeitungs-Modus](#diagramm-editor) gewechselt werden. Die untere Hälfte
zeigt alle zugewiesenen Tags an.

Am unteren Rand, neben dem Diagramm-Namen, kann das Diagramm umbenannt
oder gelöscht werden.

## Tags

Am linken Rand befindet sich die Tag-Liste. Sobald die Maus über einen
Tag geschoben wird, kann dieser bearbeitet oder gelöscht werden.

Beim Bearbeiten ist es möglich, den Namen und die Farbe anzupassen:

![](images/overview-tag-edit.png)

Über einen Klick auf einen Tag wird nach diesem gefiltert. Der Tag ist
dann grau hinterlegt. Es kann nach mehreren Tags gefiltert werden, wenn
mehrere angeklickt werden.

![](images/overview-filter.png)

### Tag einem Diagramm zuweisen

Tags können per Drag&Drop auf die Diagramme gezogen werden und sind
anschließend diesem zugewiesen.

### Tag von einem Diagramm entfernen

Durch einen Rechtsklick auf den zu entfernenden Tag in der Tagliste des
Diagramms wird dieser vom Diagramm entfernt.

# Diagram-Ansicht

Im Ansichtsmodus kann das Diagramm als komplette Seite dargestellt
werden. Während sich ein Diagramm im Ansichtsmodus befindet, werden alle
30 Sekunden die Statuswerte aktualisiert.

Diese Ansicht eignet sich gut um Diagramme auf dem IcingaWeb2-Dashboard
anzeigen zu lassen.

## Optionen

Zur optimalen Darstellung gibt es mehrere Parameter die in der URL
mitgegeben werden können. Als Basisadresse nehmen wir in diesem Beispiel
ein Diagramm mit dem Namen BeispielDiagram und den Icingaserver auf
Localhost.

`Adresse = https://localhost/icingaweb2/vision/view?name=BeispielDiagram`

### Ausblenden von Icingaweb2 UI

Hiermit wird nur noch das Diagramm im Browser dargestellt. Das komplette
IcingaWeb2 Frontend wird ausgeblendet.

`Adresse + &showFullscreen&showCompact`

### Beschränken der Größe

Hiermit kann die maximale Größe des angezeigten Diagramms angegeben
werden. Dies ist beispielsweise beim Darstellen als Dashboard Widget
interessant, da die Standardeinstellung von 1200x800 nicht immer passend
ist.

`Adresse + &width=500&height=500`

### Border entfernen

Es gibt auch die Möglichkeit den Border zu entfernen.

`Adresse + &noBorder`

# Diagramm-Editor

Im Editor finden sich alle Werkzeuge um Diagramme zu bearbeiten und zu
erstellen.

## Editor-Browser

Der Objekt-Browser ist ein Hilfsfenster zum schnellen zuweisen von
Icinga2 Statusobjekten zu Diagram-Elementen. Der Browser besteht aus
einem Filtersystem, einem auswählbaren Template und einer Liste.

![](images/Browser.png)

### Filtersystem

Das Filtersystem entscheidet, welche Icinga2 Objekte in der Objektliste
angezeigt werden. Filterbar ist Grundsätzliche der Typ wie Host, Service
oder Diagram. Weiterführende Filter können speziell an Objekt-Attribute
angepasst werden.

Beispielsweise kann nach allen Hosts gesucht werden, dessen Name mit dem
Buchstaben "B" beginnen.

![](images/Filterrule.png)

Mehrere Filter können nach Belieben kombiniert werden.

### Template

Im Objekt-Browser kann über eine Auswahlbox das zu verwendende Template
ausgewählt werden. Hier stehen nur Templates zur Verfügung, welche auch
ein zu überwachendes Objekt enthalten.

Das ausgewählte Template wird als Thumbnail angezeigt.

### Objekt-Browser

Alle nach der Filterung noch übrig gebliebenen Objekte werden als Liste
dargestellt.

Listeneinträge können per Drag and Drop auf das Canvas gezogen werden.
Dabei gibt es zwei verschiedene Verhaltensweisen.

#### Neu-Erstellung

Beim Drop auf eine leere Canvas-Fläche wird ein neues Diagramm-Element
erstellt. Dieses neue Element orientiert sich an dem ausgewählten
Template und bekommt direkt das Icinga2-Objekt vom ausgewählten Eintrag
zugewiesen.

#### Zuweisung

Beim Halten der Strg-Taste während des Ziehens und Drop auf ein
bestehendes Diagramm-Element, wird dem bestehenden Element das
Icinga2-Objekt vom ausgewählten Eintrag zugewiesen.

## Editor-Canvas

Das Canvas ist die Zeichenfläche auf dem das Diagramm entsteht. Es
können folgende Aktionen durchgeführt werden:

### Positionieren

Alle selektierbaren Elemente auf dem Canvas können positioniert werden.

Dazu müssen die ausgewählten Elemente mit der Maus verschoben werden.

### Dimensionieren

Alle selektierbaren Elemente auf dem Canvas außer Polygone und Gruppen
können dimensioniert werden.

Dazu muss an einem der, bei der Auswahl erscheinenden, Hilfsrechtecke
gezogen werden.

### Verbinden

Wenn sich das Canvas im Connection-Modus befindet und die Shift-Taste
gedrückt gehalten wird, können Connection-Nodes erstellt werden.

Diese Connection-Nodes können dann per Drag and Drop verbunden werden.

### Kopieren

Alle Canvas-Elemente, ausgenommen Gruppen, können jederzeit kopiert
werden. Dazu muss die Auswahl zusammen mit den Tasten Strg und Shift,
mittels der Maus, gezogen werden.

### Anhängen

Bilder, Statusicons und Textfelder können an andere Elemente angehängt
werden.

Dazu muss das anzuhängende Element auf das Zielelement positioniert, die
Strg-Taste gehalten, und die Maustaste losgelassen werden.

### Löschen

Alle selektierbaren Elemente auf dem Canvas können gelöscht werden. Dazu
müssen die jeweiligen Elemente lediglich selektiert und danach die
Entfernen-Taste gedrückt werden.

## Editor-Einstellungen

In den Einstellungen sind die Konfiguration der Canvas-Größe und der
Zoom zu finden.

![](images/SettingsEditor.png)

### Canvas-Größe

Hier kann über Input-Felder die Höhe und Breite der Canvas-Malfläche
gesetzt werden.

Mithilfe der Plus und Minus Buttons kann das jeweilige Canvas-Attribut
direkt um 100 erhöht oder verringert werden.

### Zoom

Mit dem Zoom Slider kann die Ansichtsgröße des Canvas verstellt werden.
Solange der Wert nicht 1 ist werden alle Möglichkeiten zum Verändern der
Canvas-Größe deaktiviert. Der Zoom wird beim verlassen der Settings
zurückgesetzt.

Der Zoom-Modus ist hauptsächlich für den Zweck geeignet Polygone in
jedem beliebigen Detailgrad auszuarbeiten.

## Editor-Palette

In der Palette befinden sich alle auf das Diagramm ziehbaren Elemente.
Zum einen im oberen Bereich die Basiselemente und zum anderen die
Templates, ohne Überwachungs-Verlinkung, darunter.

![](images/palette.png)

### Basis-Elemente

#### Rechteck, Diamant und Kreis

Hierbei handelt es sich um einfach Basisobjekte. Sie weisen sonst keine
Besonderheiten auf.

![](images/objects/Oval.png)
![](images/objects/Diamond.png)
![](images/objects/Rectangle.png)

#### Textfeld

Elemente zum Anzeigen von Text.

![](images/objects/Text.png)

#### Polygon

Das Polygon ist ein besonderes Element. Es kann nach belieben mit
weiteren Punkten erweitert und somit komplett nach den eigenen Wünschen
angepasst werden.

![](images/objects/Polygon.png)

#### Statusicon

Das Statusicon ist ein Objekt, welches lediglich zum Darstellen eines
Status benutzt werden kann.

![](images/objects/StatusIcon.png)

#### Bild

Das Bild-Element kann hochgeladene Bilder darstellen (png, jpeg, gif, etc.) . Ausgenommen sind
SVG-Bilder.

![](images/objects/Image.png)

### Template-Elemente

Hier werden alle Templates zur Auswahl angeboten, die keine
Überwachungs-Verknüpfung haben und können genau wie die Basisobjekte auf
das Canvas gezogen werden.

Falls ein Template aus mehreren Objekten besteht, werden diese bei der
Erstellung gruppiert.

## Editor-Toolbar

In der Toolbar sind allerhand Editierungshilfen und Operationen für das
Arbeiten mit den Objekten auf dem Canvas zu finden.

![](images/toolbar.png)

### Undo/Redo

![](images/toolbar/undoredo.png)

Wenn Änderungen auf dem Canvas vorliegen kann mithilfe der
Undo/Redo-Buttons vor und zurückgegangen werden

### Speichern

![](images/toolbar/save.png)

Dieser Button ist zum Speichern des Diagramms.

### Crop

![](images/toolbar/crop.png)

Mithilfe des Crops wird die Canvas-Größe an die vorhandenen Elemente
angepasst.

### Grid-Modus

![](images/toolbar/grid.png)

Während sich das Canvas im Grid-Modus befindet, wird im Hintergrund ein
Hilfsraster gezeichnet, an dem sich die Elemente orientieren.

### Snap-Modus

![](images/toolbar/snap.png)

Während sich das Canvas im Snap-Modus befindet, positionieren sich
Elemente in Abhängigkeit zu anderen Elementen.

### Connection-Modus

![](images/toolbar/connection.png)

Während sich das Canvas im Connection-Modus befindet, können
Connection-Nodes erstellt und gelöscht werden. Auch das Erstellen von
Verbindungen zwischen diesen ist dann möglich.

Um Connection-Nodes zu erstellen/löschen muss die Alt-Taste gehalten und
mit der Maus an den gewünschten Ort geklickt werden.

### Unlock-Modus

![](images/toolbar/unlock.png)

Während sich das Canvas im Unlock-Modus befindet können gesperrte
Diagramm-Elemente wieder ausgewählt und entsperrt werden.

### Group

![](images/toolbar/group.png)

Mithilfe dieses Buttons kann die momentane Auswahl gruppiert werden.
Falls die aktuelle Auswahl nur eine Gruppe ist, wird diese wieder
aufgelöst.

### Front/Back

![](images/toolbar/frontback.png)

Mit diesen Buttons kann das ZLayer der Diagramm-Elemente verändert
werden.

### Reload

![](images/toolbar/reload.png)

Hiermit kann das Aktualisieren der Statuswerte des Diagramms angestoßen
werden.

# Template-Editor

Über den Template-Editor ist es möglich, verschiedene Vorlagen für
spätere Diagramme zu bearbeiten und zu erstellen.

Es gibt zwei verschiedene Typen von Templates. Für die
[Palette](#editor-palette) und für den [Objekt-Browser](#editor-browser). In
der Palette tauchen alle Templates auf, auf denen sich kein Element mit
einem überwachten Objekt befindet und im Objekt-Browser lassen sich alle
Templates finden, auf denen mindestens ein Element mit einem überwachten
Objekt platziert ist.

Um ein überwachtes Objekt hinzuzufügen, ist dies ähnlich wie bei den
[dynamischen Attributen](#dynamische-attribute). Einziger Unterschied ist, dass
kein spezifischer Host oder Service ausgewählt wird, sondern diese
Überwachung nur aktiviert wird:

![](images/template-configmenu.png)

Das überwachte Objekt hängt dann davon ab, welcher Host oder Service
über den [Objekt-Browser](#objekt-browser) in den Editor gezogen wird.

## Template-Browser

Der Template-Browser bietet die gleichen Funktionalitäten wie der
[Editor-Browser](#editor-browser).

## Template-Canvas

Das Template-Canvas bietet die gleichen Funktionalitäten wie das
[Editor-Canvas](#editor-canvas).

## Template-Einstellungen

Die Template-Einstellungen bieten die gleichen Funktionalitäten wie die
[Editor-Einstellungen](#editor-einstellungen).

## Template-List

Am rechten Bildschirmrand befindet sich die Liste der gespeicherten
Templates.

![](images/templates.png)

Es ist möglich die Templates umzubenennen, zu kopieren und zu löschen.

Durch einen Klick auf eines dieser Listenobjekte wird das jeweilige
Template im nebenstehenden [Template-Editor](#template-editor) geöffnet.

## Template-Palette

Die Template-Palette besitzt die gleichen Funktionalitäten wie die
[Editor-Palette](#editor-palette), mit dem Unterschied, dass hier keine
Templates auftauchen.

![](images/template-palette.png)

## Template-Toolbar

Die Toolbar im Template-Editor ist eine abgespeckte Version der
[Editor-Toolbar](#editor-toolbar). Die einzelnen Buttons haben aber die
gleiche Funktionalität.

![](images/template-toolbar.png)

# Editor-Konfigurationsfenster

Das Konfigurationsfenster ist das wichtigste Bearbeitungstool in den
Editoren. Mit dessen Hilfe können erweiterte Attribute wie
beispielsweise Farbe, Text, Verlinkung und Connection-Typ gesetzt
werden.

Zum einen ist es möglich Werte festzusetzen, wie eine gleichbleibende
Farbe oder Größe, zum anderen können aber auch spezielle Werte, wie eine
Statusfarbe oder Objekt-Verlinkung in Abhängigkeit zum überwachten
Icinga2 Objekt, gesetzt werden.

## Beispiel Konfigurationsfenster eines Rechtecks:

![](images/Config-Window.png)

Um das Konfigurationsfenster zu öffnen, muss ein Doppelklick auf das
gewünschte Element gemacht werden.

## Dynamische Attribute

Diese Attribute hängen von dem überwachten Icinga2 Objekt ab. Als
überwachte Objekte können Hosts und Services gewählt werden.

### Beispiel: Gesetztes überwachtes Objekt

![](images/Monitoring.png)

Diagramm-Elemente, die ein überwachtes Objekt gesetzt haben, zeigen beim
Hover mit der Maus einen Tooltip an.

### Beispiel: Tooltip

![](images/Tooltip.png)

### Hintergrundfarbe

Die Hintergrundfarbe orientiert sich am überwachten Objekt.

![](images/BackgroundColorMonitored.png)

### Rahmenfarbe

Die Rahmenfarbe orientiert sich am überwachten Objekt.

![](images/BorderColorMonitored.png)

### Text-Macros

Sobald ein überwachtes Objekt zugewiesen ist, können Macros zum Text
ergänzt werden. Dazu muss das "$" Zeichen innerhalb des Editors
geschrieben werden. Daraufhin öffnet sich das Macro-Menü.

![](images/Macro.png)

### Verlinkung

Wenn ein Objekt verlinkt ist, kann im Ansichtsmodus per Klick auf
das Element die Detailansicht des verlinkten Objektes geöffnet werden.

![](images/LinkMonitored.png)

## Feste Attribute

Diese Attribute können fest gesetzt werden.

### Form-Werte

Dies sind die Basis-Attribute von der Größe und Position

![](images/config-window.png)

#### Position (x/y)

Kann bei allen Elementen außer Verbindungen gesetzt werden.

#### Dimension (Breite/Höhe)

Die Breite kann bei allen Elementen außer Verbindungen gesetzt werden
und die Höhe kann nicht für Verbindungen und Textfeldern festgelegt
werden.

#### Größenverhältnis beibehalten

Kann bei allen Elementen außer Verbindungen, Textfeldern und (Polygonen,
ohne festgesetzten Rand) gesetzt werden.

#### Figur Sperren

Macht das Element unanklickbar. Kann bei allen Elementen außer
Verbindungen gesetzt werden.

#### Transparenz

Macht das Objekt durscheinend. Kann mithilfe des Sliders angepasst
werden.

### Rand Festsetzten

Bei festgesetztem Rand kann ein Polygon genauso wie ein Rechteck
verwendet werden.

### Hintergrundfarbe

Die Hintergrundfarbe kann bei Rechtecken, Kreisen, Diamanten, Polygonen
und Textfeldern gesetzt werden.

![](images/BackgroundColor.png)

### Rahmenfarbe

Die Rahmenfarbe kann bei Rechtecken, Kreisen, Diamanten, Polygonen,
Verbindungen und Textfeldern gesetzt werden.

![](images/BorderColor.png)

### Text

Der Text kann nur bei Textfeldern gesetzt werden.

> Um den eingegeben Text zu setzen muss einmal die `ENTER`-Taste gedrück werden.

![](images/Text.png)

### Bild

Das Bild kann nur beim Bild-Element gesetzt werden. Um ein Bild fest
setzen zu können muss es zuerst über den oben befindlichen Upload-Button
hochgeladen werden.

Alternativ kann auch das überwachte Diagram als Bild angezeigt
werden.Dazu muss lediglich ein Diagram als Überwachtes Objekt
eingetragen sein und der "Monitor Diagram" Hacken gesetzt werden.

![](images/Image-Manager.png)

### Verbindungen

![](images/ConnectionConfig.png)

#### Verbindung-Typ

Hiermit kann die Art der Verbindung verändert werden. Zur Auswahl
stehen:

| Name      | Image                                         |
|-----------|-----------------------------------------------|
| Direct    | ![](images/connections/conType_direct.png)    |
| Rubber    | ![](images/connections/conType_rubber.png)    |
| Spline    | ![](images/connections/conType_spline.png)    |
| Manhattan | ![](images/connections/conType_manhattan.png) |

#### Verbindung-Style

Hiermit kann der Zeichenstil der Verbindung verändert werden. Zur
Auswahl stehen:

| Name            | Image                                                |
|-----------------|------------------------------------------------------|
| Full            | ![](images/connections/conStyle_full.png)            |
| DotDotLongDash  | ![](images/connections/conStyle_dotDotLongDash.png)  |
| DotDotShortDash | ![](images/connections/conStyle_dotDotShortDash.png) |
| Dots            | ![](images/connections/conStyle_dots.png)            |
| DotShortDash    | ![](images/connections/conStyle_dotShortDash.png)    |
| LongDash        | ![](images/connections/conStyle_longDash.png)        |
| ShortDash       | ![](images/connections/conStyle_shortDash.png)       |

#### Verbindungs-Dekoratoren

Hiemit kann der Start und Endpunkt einer Verbindung angepasst werden.
Zur Auswahl stehen:

| Name    | Image                                        |
|---------|----------------------------------------------|
| None    | ![](images/connections/conDecor_none.png)    |
| Arrow   | ![](images/connections/conDecor_arrow.png)   |
| Bar     | ![](images/connections/conDecor_bar.png)     |
| Circle  | ![](images/connections/conDecor_circle.png)  |
| Diamond | ![](images/connections/conDecor_diamond.png) |

#### Verbindung-Richtungen

Bei den Verbindungs-Typen Spline und Manhattan ist es relevant in welche
Richtung sie zeigen. Zur Auswahl stehen:

| Name  | Image                                      |
|-------|--------------------------------------------|
| Up    | ![](images/connections/UpDirection.png)    |
| Right | ![](images/connections/RightDirection.png) |
| Down  | ![](images/connections/DownDirection.png)  |
| Left  | ![](images/connections/LeftDirection.png)  |

### Anhang-Richtung

Angehängte Elemente können werden in Relation zum Basiselement
positioniert. Zur relationalen Positionierung sind Lokatoren zuständig.
Der Standard Lokator ist "Top", welcher wie der Name erschließen lässt ,
das Element oberhalb des Basisobjektes positioniert.

![](images/AttachPosition.png)

#### Aufzählung aller Lokatoren:

- Top

- Right

- Bottom

- Left

- Center
